
From: <gerg@snapgear.com>

A couple of additions to the linker script for m68knommu platforms:

. add support for COBRA5272 and COBRA5282 boards
. link in .rodata.str1 generated by gcc-3.3.x compilers


---

 25-akpm/arch/m68knommu/kernel/vmlinux.lds.S |   21 +++++++++++++++++++++
 1 files changed, 21 insertions(+)

diff -puN arch/m68knommu/kernel/vmlinux.lds.S~platform-additions-in-m68knommu-linker-script arch/m68knommu/kernel/vmlinux.lds.S
--- 25/arch/m68knommu/kernel/vmlinux.lds.S~platform-additions-in-m68knommu-linker-script	2004-04-07 20:28:04.590417936 -0700
+++ 25-akpm/arch/m68knommu/kernel/vmlinux.lds.S	2004-04-07 20:28:04.594417328 -0700
@@ -122,12 +122,31 @@
 #define	RAM_LENGTH	0x3e0000
 #endif
 
+/*
+ *   The senTec COBRA5272 board has nearly the same
+ *   memory layout as the M5272C3.
+ *   We assume 16MB ram.
+ */
+#if defined(CONFIG_COBRA5272)
+#define RAM_START   0x20000
+#define RAM_LENGTH  0xfe0000
+#endif
+
 #if defined(CONFIG_M5282C3)
 #define	RAM_START	0x10000
 #define	RAM_LENGTH	0x3f0000
 #endif
 
 /*
+ *   The senTec COBRA5282 board has the same
+ *   memory layout as the M5282C3.
+ */
+#if defined(CONFIG_COBRA5282)
+#define  RAM_START   0x10000
+#define  RAM_LENGTH  0x3f0000
+#endif
+
+/*
  *	These flash boot boards use all of ram for operation. Again the
  *	actual memory size is not important here, assume at least 4MiB.
  *	They currently have no support for running in flash.
@@ -202,8 +221,10 @@ SECTIONS {
 		*(.rodata) *(.rodata.*)
 		*(__vermagic)		/* Kernel version magic */
 		*(.rodata1)
+		*(.rodata.str1.1)
 
 		/* Kernel symbol table: Normal symbols */
+		. = ALIGN(4);
 		__start___ksymtab = .;
 		*(__ksymtab)
 		__stop___ksymtab = .;

_
